## Subresource Integrity

If you are loading Highlight.js via CDN you may wish to use [Subresource Integrity](https://developer.mozilla.org/en-US/docs/Web/Security/Subresource_Integrity) to guarantee that you are using a legimitate build of the library.

To do this you simply need to add the `integrity` attribute for each JavaScript file you download via CDN. These digests are used by the browser to confirm the files downloaded have not been modified.

```html
<script
  src="//cdnjs.cloudflare.com/ajax/libs/highlight.js/11.6.0/highlight.min.js"
  integrity="sha384-er8Ado8J22AgUnqsiLVTJLKit6HlrmKK8nCMKuy/2QyVIU/wYuf+vHu5ESJ81K+p"></script>
<!-- including any other grammars you might need to load -->
<script
  src="//cdnjs.cloudflare.com/ajax/libs/highlight.js/11.6.0/languages/go.min.js"
  integrity="sha384-KKxWZNXJfFb+3umsY6tIO7YaCcBBKOiRhpckgJSUQifmlBq7Mislp9WreVfCO3By"></script>
```

The full list of digests for every file can be found below.

### Digests

```
sha384-er8Ado8J22AgUnqsiLVTJLKit6HlrmKK8nCMKuy/2QyVIU/wYuf+vHu5ESJ81K+p highlight.min.js
sha384-lYI4xxLAYHnl79uGPmLof0ey4IPRT446HfqwiV0SLrOJzxfAJwksUZnBFr7GZjaC highlight.js
sha384-vhUPHjV4rCyN5ywjOX3t0ff6jabazDuVg820exbXGBk317w1Pb3dL939NsTv0rHO es/highlight.min.js
sha384-u6Ccl6RKndmtwPn4y0l/hv9pR6PRoMEcVlB7khcGgtB5IyPRcGdp6xlNCHA27Mh2 es/highlight.js
sha384-vhUPHjV4rCyN5ywjOX3t0ff6jabazDuVg820exbXGBk317w1Pb3dL939NsTv0rHO es/core.min.js
sha384-u6Ccl6RKndmtwPn4y0l/hv9pR6PRoMEcVlB7khcGgtB5IyPRcGdp6xlNCHA27Mh2 es/core.js
sha384-tjB+RVwQsmjY+pIK3fL3Tli1UyYDYCd/kcdgcClOKmmgwPI9XtoOg4tujdHJ4msc languages/abnf.min.js
sha384-bdFIO5FXq3ibqpoUaOVzqaQWZwt3yQV5+Lui84U5Ojq/VcSS6AnshEj/BOB3olmq languages/ada.min.js
sha384-th8D+n4rpptGLUE5tHjHVOxEKcSOy7Xy97d013A+ZIndwejpu04ryQVO4koI37Dw languages/accesslog.min.js
sha384-9iMAiIAGVIlV+W0Z4KCVXFWpkFYTeIjVPd9kOHBH7DrwwH2Z6WvrzY2TykQMr20B languages/actionscript.min.js
sha384-dxYrwqGRF9DbGY7Rr9sGoRkYXGDHmOXK2rISGygls2H+tbSjPN3XCMaJ+a9yMtcP languages/angelscript.min.js
sha384-fEGz7vKif4+2HZgn/mhNvHerawo9skaeSUkGcG8HRxVOmMXaEry79oQyS8SQlskL languages/apache.min.js
sha384-I7L8Pxs7iIVO/stX/PXu4d/kGmpluyR+tMgJzuyX+Vx0YgS0AfS2QW+nSiKPlRWI languages/applescript.min.js
sha384-yyNdcav7cAIQs2RSPeg1txIlbgWmBfviKZQkY1qzj3xxTKuvkqSr2ewjCPV4JWz8 languages/arcade.min.js
sha384-yh44RubWCuxnN0s9yrFuiABb1XC+dUK5MQj/g1w3C5HiP0JBPq9gVuay1iPOru0V languages/armasm.min.js
sha384-OxEpc8oRQx7APC1EZwVh8L2NQfOxaZREmRmRdgsMbdN3L1eXR6JRHlqIeM+FDsBO languages/asciidoc.min.js
sha384-5Ji/ogL5jENrQ6jhjrcJvjAXfIcQs8V8zWNjgmzCtNMUnNmJNWMgVTp6c8Dtvfx1 languages/aspectj.min.js
sha384-jH+p3a60hUGsjLNk22St9vfwlvAhadwNgCsvWC++ZVE6dUmgHwjBePxpqBaaPRtz languages/autohotkey.min.js
sha384-E+8uVQzkod4emmlznH/4plR/5VkYoNTv2WOl8Raw8wk6aoq3yEehFOaTDZ2eq/H6 languages/autoit.min.js
sha384-j6BkVKGH8lUNYF4XRTSHry47Kxe+EiEFAxYvWjlRSl4HZ64x3NcZXJbAH3SyFHkn languages/avrasm.min.js
sha384-olLM22aEi4gdDO9dR6zd0/xZvY2LmkQq3CB2KEBp2bvF0b7cmJrO2TxlWRK+woCJ languages/awk.min.js
sha384-EOeGuA4mTTPrIWVkJSo0NBSwL3A1itrb/mtbjfGOEJeMO4kOwHHXnra86HJhCYSe languages/axapta.min.js
sha384-LvbMx07lQj+VRlQsEOWzxp/cBpRANfGwykWNRGPa1M3bUv0txxx8wl15r+B/iWCw languages/bash.min.js
sha384-keWNT79KLPmkGTo4qSTUD6zhEs5wi7L3liKD4uk46468XHHF35DTIGW0w2ETLqey languages/bnf.min.js
sha384-IUOphWBWNC/UgWJzyhEn8cgrbUTV+EH80RB0FRj+VwreptQeFEpVPAtqTunLTVP7 languages/basic.min.js
sha384-GSItQOmLqz+X99GkcN2oNJGJjjfqspq+4QPDjxJwi9LaNgX73MIzQ0C23te9vJHF languages/brainfuck.min.js
sha384-kEyoMtPyPqQbM9zaXEWym7I2p/Q94E9GO1OQQ5ep4w+T6NLNl3DSm2i7ApqkCRwD languages/c.min.js
sha384-g0CfPCTD+aD2mGQcn//K4sqDG+0Fli1BAre0FfdBYMd7Ahp0CYZ0GfQnmbyNOOSw languages/cal.min.js
sha384-TJuo95WKvq4dBY4+vDf8tCIkrCUGTmd9asENpObeLBn7IJ5pLJws5jvw288dcnuX languages/capnproto.min.js
sha384-gRFsXFZhDe2vXJ3Iqxwsoqq5rHiJpEVimfe6qLzA9ux4RrbkEa58mtS4JfBITFmh languages/ceylon.min.js
sha384-7UqATQqiaImXTEx+j5aT2s74p/F9EvEMdJ6z2+x2vBIH1tyYW6YgqxOVH/v1MCBI languages/clean.min.js
sha384-HpTEhw87V3dcGCJiqD1PolFbPuFH/Giuor9FQ5QlubuBS9MrMBQzH0a/ashYj/lV languages/clojure-repl.min.js
sha384-jPGjwgMBWImUeygXyZxodmXx3MU8z1u90p8UfIewxfe1ZXe0B066PStRfcVeN12F languages/clojure.min.js
sha384-xBbstSyBRGHDCS/KgTkmCujhPjdhSQK4IgexEAIX+DEVHJQDMJMdLNww/hPOob8G languages/cmake.min.js
sha384-qSKTCDLavuYP7Fhk/WOFpVmwLXA5wdMjvU3EYAZGcz6sNSLlJM0RAEjOpqTWHIxx languages/coq.min.js
sha384-HFHa21+7QR0ylfbvEZBUYEu+HBHy/+6fd2waltkQy8bl4t2k0ZmjAdPByHxDmY4a languages/cos.min.js
sha384-0nKHEkS01sWWpEl+YVUorM6yXoydtxP+wxPYGq8bYqisiQBB22sgV/ZoMTrV9ZL0 languages/cpp.min.js
sha384-ENtDQUatWxry1g44Av9OChssfyuN0xUwfUSt6p5A+cUK5p4JGDNFgFsR+dMcZYbH languages/crmsh.min.js
sha384-3JziQrWXRFodHBjb5eRjsUZMFwzmfvZAzbXcg713QUY0yqXCQ2m2mox8jqrTeCC4 languages/crystal.min.js
sha384-gp+SISILkiGs3mSi/6VwAm5T65CMGRfCZvtDoUI8tjrS5nc+/nhdHhc75mgHYTnb languages/csharp.min.js
sha384-jOp9PcFPkI029Lh6d0kio7ZxljRApjnLKgbj/r21q61+Qx1AqnEEyLLEXDA8dvdG languages/csp.min.js
sha384-oKTdGdKPpqq9VuEjrIIrJDTvm7Zhoaq5TNXgcG5Td3G/SP1KW8PoPyyEvltIt2Sc languages/d.min.js
sha384-MFcqjNvhcxi7XQc+RW8VRy4Eqjr+AdxSg51RKAqXB2tyEOphntDIYntTDCLj+pLa languages/dart.min.js
sha384-mC00px5MOg+8ZO1Z3zkMtnuNIokqbPeF2/w9gwSP4DI32jhWxeG4W6CxoEFysUxM languages/delphi.min.js
sha384-SaA+j8AUH56+L9RQ2bLpSuYz9RwXk35QgjUrpP8fXVuCUJu85BlJazA+/9B3VSHo languages/diff.min.js
sha384-mPAbJGAmQmXCkcvOCF2bT5jai7p+PlrwQ7w21YP61hN8ipQ1cJTy/UafL3Ow59Fy languages/django.min.js
sha384-+xHNsveCgv1y2uYuhnHjSbNMq+KvrS3FOxaggb88NtBEddRmCbFmZCXbtREC/q/o languages/dns.min.js
sha384-SZCmCsL5lGGUkN3R2334IDT47uO66WzkmUifj7Y6FJE2gKUQLZVHqVtuMlPjVlrE languages/dos.min.js
sha384-LaDHzcNGyIMYVXrEWRAx0PVCQPyqZ4Y5CXNWnVS19eyh5jAaS1rOM5gvyZJofo0X languages/dsconfig.min.js
sha384-9pJ1wRhBF62JiqH5JOy2yDgqBZRHbioRVarqL5f05FLz2Yz+EJ9iHD/BZ+KE8jTb languages/elixir.min.js
sha384-3wpjjfiYVDT1dwx5t3zDCbSB5sku83kSHNKzR1I6r5Xu1fbht5Pr46TE8+Q14NtU languages/elm.min.js
sha384-RCISTMFB3Wv85Ck4gYAYSQeocKa+XvL6KnZyuaFZDTsA3De5uR8wIjOdIkj5rpha languages/erb.min.js
sha384-XdFgHs8sERwq1JxbE/rCrietjy6zTevcaBMV9kf9NeKbaKVpEQ+TEo2nyr8GdbS1 languages/erlang-repl.min.js
sha384-ZrZvNHBBvcESN24Oigc1tj1+Hb1l9fU9bPLNCDdj4Zvjek7VI5TYHGdpM3Wwwfjk languages/erlang.min.js
sha384-XTxU+DxYb96pV7Wl5JxJ28VsVK4AAVLakCoH9CTXYENDVTfwzd2oYhpWY9HukQAZ languages/excel.min.js
sha384-THdov/WwUiCW1nMTYW2ALOq/r8xqtohOI6+HRpFYspdMla/+0KpmNaOg7r9XGhH8 languages/fix.min.js
sha384-pgh0QRQk9DTKVO7NINqcjz3uAZkR7ZsM7lmc7cobL0YDEnBONTjcO47LWGCRbTkT languages/flix.min.js
sha384-9yUdZD4kJlJtk4dYD2me6syOveAkKSyxMQbGAkiF0Y5a79a2UtLKmGGtEc1nP5HI languages/fortran.min.js
sha384-VGbzb2PZLLV8KU4Ylv4okmp0a6MElS8o0H6Ivlf91XfNctxuYUH7O0C0WDDO5GRO languages/gams.min.js
sha384-cs6Afsu+zVMJzc8plC5qrmCpadZztG+XrnAfgqHJzhBbGP9qBjad70DX9DTD/uwP languages/gcode.min.js
sha384-iNJeoJ6cxSwVbsWkCAWhEmi4wQtl35STx6DUMR3xBT1aF+O5LrZMQ3GNSK2YGaxw languages/gherkin.min.js
sha384-Wc81xrpEn4D1h+Z/5zXeWaT7tNHdKc2CcEnyA+0HuIAP0dYIZ7KQ2E4bncfUBuGJ languages/glsl.min.js
sha384-KKxWZNXJfFb+3umsY6tIO7YaCcBBKOiRhpckgJSUQifmlBq7Mislp9WreVfCO3By languages/go.min.js
sha384-VvpIyR0XbXPuGlKh6PvXMOCidTaAJvO8RS9dxw73EioMxhP008RA+YM7fb3JXd5S languages/golo.min.js
sha384-RCJZmkYDGXhLVGuoG/+Pin+Tclivn7l6BIRKhGahWVlWUlNsU+ZHa/l9pF6zHMb7 languages/gradle.min.js
sha384-3KuLGwNYkTqbpRKKzW2T2DnhTRCiC0laOUK2VQiLIc0GQxWCZjEcJPIeiX14g+5t languages/graphql.min.js
sha384-t3YyWFeuw8MyGP9CczUNI1hieubNAV5/0ciLuSXroitGJOWELDarndAnW2acYBMj languages/groovy.min.js
sha384-NwkYGmUggMd4/raGebL+ACLpekH5mb0v8oW7Zf6+6jDnYzZkIz1vtu95+R62B2Qm languages/haml.min.js
sha384-jvFZwDnw5w6k15DwuYcGUOSkYEKd5nFBLXV2i7DCRyLbCyfl7wsz4f6ilsNhxTKS languages/handlebars.min.js
sha384-vtrqRhx+7AQMT0jJViGWKKmngaE/1pzL+nNCz0vVMckMr8Bdx0Z2VBvFIPPOJqm2 languages/haskell.min.js
sha384-uv+oJkjt6bKxUtBn5DgYaz3aGkmGcsNXMZKhlnEtizUwXPX2BR8P+UiSIRqZq6Iq languages/haxe.min.js
sha384-HZaUJQDI7gYtjWybt+bvaQC6G/Aer8TM4wRnf0qlGvuMyI09uEZUgEBnWAXYuCJz languages/hsp.min.js
sha384-8n/riS3gs3MJAz06Bgl18qTmcf49Pk/gHjxKkHvzD1pPo3Om1iMqo+IZPsi1aZDG languages/http.min.js
sha384-nfPffUJRsDwY9bYpTTpjUx2Sgk9R5LdF8tBcVcP9zkRpMtOidNS8F7obNiqZFDss languages/hy.min.js
sha384-pqKFkHS0DYq16wxD67Cu4Nlek91OaeOpW6JMcTcRS5EQvIsiRT2eeZ6WkXIp43Q0 languages/inform7.min.js
sha384-DS+9yZkECqp8knlaM/+UyJjzFKlYOlaIvn6Ki0DYOZzdhU2NKLNj3HTUTE9x25M3 languages/ini.min.js
sha384-1kSiuzoyNH0IegjBhyrTd+G0gpWOP/ENq2BbHSDKqFAeNg+akBDcPHs06jMmn0qR languages/irpf90.min.js
sha384-z9M1SSS5ZmK7p7+gTlA9gRGxE3Y7Y4LjcRIJ3V4dMZ/QOtiUhpVEixF36ReyMPfB languages/jboss-cli.min.js
sha384-Iwphfwon0gTejRcI42A0Of+WwLL28YudnPDg14Kda90NzBr/AxsyO7Db03IvyyOe languages/json.min.js
sha384-fWWLi1SiZrnj7rtmWTGQ6w9q9eep9siiHdyLghN/vygMyp41KHoV6Q2Txc+y5iH7 languages/julia-repl.min.js
sha384-dkaWkgB8A4w8qXYiO0oe9ar6bp5m4K54B4qYyPUjMNzUCplVzkXND0941tmwEnWG languages/julia.min.js
sha384-ccNljb8Kv/Gc5Jmrln8TEwiHwh3csjLt/gfoZAMv1vGJt/7CYpnl2w3zMFvpaEWR languages/latex.min.js
sha384-lnS82BTejNp9m/ADP1NuGwJREsINKPtfHRElDGQOHK1gnyfhKLBzbdcZGqo6ZTK2 languages/ldif.min.js
sha384-VaM8oXyM+h9NE2aI1F9X6yP3IeuM6ldbr6fwUAcnLAh+ZZWDH5iviBS0CG+rzP/s languages/leaf.min.js
sha384-YUM5qSzQ1SyTG39iuwMzzEzxAOZhdJs386zE2dFvlUYHO3+C38dJI8G5mB15HrJn languages/lisp.min.js
sha384-OVkOcy7gG/iPK6vJLtSVhFpQ01PSQJ5HIwfk9tLouwYwdCL9TWJ47KQ7bhKPsqKo languages/livecodeserver.min.js
sha384-NU7Ccjab3Xn6aBfdVRbzQlKzAzSp9xhll+WRQpSj2ae9zgp5cVK3PfXO2O9XQki6 languages/llvm.min.js
sha384-uNJxReWFeNjIX2LJdPhCPlQxcOKuaymAhESvdbFkPAUWI65Yu4ZgaOc5AUdxuynf languages/lsl.min.js
sha384-NJTOWqrFYFBeDUFPJJ9L0frvh1X5yMP71XWxSKwLZN2jtwnMux21KAmzttP8vF02 languages/lua.min.js
sha384-D8aJInk73yR1nnlO/7oKqp/U70FhVyVZww2zz4syDySf3JRbwJDriP8dI7l5pznV languages/makefile.min.js
sha384-o3KOeOhbPRHrnruGEFQb3KyMrCShpTSOatvgfMN9DJQggaXRbu9O9G5mmv3lg/6+ languages/markdown.min.js
sha384-kIqxSXwTLEY+zdxM3vfq0zk2Z1JU0LVArqitH8mq/L7nM7yLYlbzT33zNghMpWLx languages/matlab.min.js
sha384-Y9flQycMHM9Wcc9HJ9anyvC8WBxsrlKpOaph1zZaqqbjbZpJP7OviYX8Z9Gcx5Qt languages/mercury.min.js
sha384-k0L3GuTyc3tt2EejeDBIx+LObr3vf9x7xA7Y1N+wr1eB6ocOaVb4Gv+wN5o0w6fU languages/mipsasm.min.js
sha384-uWdtVkRq1sAf1ePVPgMn3Z38UhFsza0yXBSNn0UAVas1WCZhJMZlll3O5oAoplZO languages/mizar.min.js
sha384-Cysu5GMfWOsYqpgMB3RwwCgNEA8ix2NAyWABY53WJcoyEE0YxlQmbbaAjMb35ew6 languages/mojolicious.min.js
sha384-lq+GVAZRFxveVaKtZp/sZCNRolWOxrpEmPrvh4uj/CuEqVTp3YVpRvHQC8uoWEU+ languages/monkey.min.js
sha384-qQU57fa2pKxEWz7l7iRdXDUJ/sLfKz0URyc1YNSR9X7a8AiDiC/zSQ82G/psrlc2 languages/n1ql.min.js
sha384-xdowGAjzr2HZRe3ll715w+Fm4Il0+TwAUFNTh5OtJcxWak0kQ+XXbEqO0SgRg5yU languages/moonscript.min.js
sha384-Aih3buqVukpEvex1fs1eP27/I8LaeHuSR1SgEMVpxlM+kxSUKMBC45E1YDlhd8aX languages/nestedtext.min.js
sha384-WyzcI3LUPknM7jAv62O3N81S5TFFpaXgZst4/RL0pCFT2XN3C0aCVULcuA8RIShh languages/nginx.min.js
sha384-gnrUjsObr1mUO0HSnuPxitwV3W7poHBB9f+Dy/sQcIFyLgezyfb1HGRmCgIPhKPO languages/nim.min.js
sha384-js/WKxjuK6DF+DUygbctpjpWBUrPFg5b4CK/SB/+2mizf9ApqQcPhGXvujXzW5+n languages/nix.min.js
sha384-dXKs4E9pESzcZhMOZwRZjNHpeMfmu0dknjL0WE8+q8yIa1WpwkVQ+jV2STuVSgr1 languages/node-repl.min.js
sha384-TTZdKjS3VbsY1uc9Ypxce2vuvWUtQ5MunMlS4pJBHEbdSGohGyzi6NRFqsXNn6gC languages/objectivec.min.js
sha384-7x6zuJfIKUqHQ76qnhcxuX1uDqSTJj52Dk6+X46UjnI/t+SSgXxVqHOMpKjA17Fs languages/ocaml.min.js
sha384-Jcb2D1GzMH0S6ae3VyBHi3fHQWxdC9OMDE407P9NOWj7YGiot3/FM1mnjdQ1KVnp languages/openscad.min.js
sha384-uyT+1VLorC604Oxfp6tJaTXAy5Bd66PuMdvR+7JOtt+VfW51UVDBDztfTm80yJir languages/oxygene.min.js
sha384-OCLa/fFlcH32sG2YqZJt5jMZYn+oe/czlHJAuFBuKtryg44KJTcByh+NX3iRmp/2 languages/parser3.min.js
sha384-lxH2Ro65GAAiRgn+7TFDlZtjA1oWbBN2H7lMKuEhE3GcY2CU9d89oishNMmChzgM languages/perl.min.js
sha384-dVqLLwgM4jaUz4VvCMmwgwEsPCGoLEcpBWRyzi6r9c69InsJXnMA2Le5x0GQTdW3 languages/pf.min.js
sha384-axkNMW1+9/PkVOKMlm318J3gEMXzh3EDRMS2+jDFnmETG1KeRBuANFKmFrwHt/ff languages/php-template.min.js
sha384-hoUtJX0RIw34a7HNucn5+StQBkn2lUYK5TR39zeqd0KLo+MYZ0zQ2I2FSb6NAjkj languages/php.min.js
sha384-ZeRbHXvSrKboqeBtxWwxmg6Fp+qLrPely/fR0XoRagV7jtWY5Ao+7VY+348ItQIP languages/plaintext.min.js
sha384-YbCVp3SGqh9z5ortBh0X5yloRgi/Ba/mOF4+PsbJwH64aVLAVwZDjhJZXTIeEKH3 languages/pony.min.js
sha384-3R2bCmkfXCE7Ml9LZGERIiubr1ECz9Tetg3lcMmpMtF6yyPlI6pteFI+vO6xwtGS languages/powershell.min.js
sha384-3wWJkmYVp7w3Yt8LDAwOO63S7t+vyNMAJRFaOXBrxP8PGZkNYirBtAsmqr6v7Rvl languages/processing.min.js
sha384-pxsSMAXWQsOLk17YvG8KmMaBDM5k+lSJcRzXZycVb22R8gw/j19JJvRIrCyr1td1 languages/profile.min.js
sha384-cMonFQek6jvgEvITnm6AFcT1ZRJ9QCYFd37n/wWul1CrtDbjxEfMObOnszFT4m5E languages/prolog.min.js
sha384-4Q0YvPjKYclGE8++hmt1z9g8o22YyW02msVSHFM1rZu4UUW1cICfVMmZb2burCc1 languages/properties.min.js
sha384-E3CIVbh7ssA9veSvF4FptRvZofPz3rInDJ2P/JTZvdSv6qCGuM6OvOuWueGuTPSB languages/puppet.min.js
sha384-28FSGE6GC2hhvaYtZ92+knfvT0vFWFz2rEmpOkm/+EZN0oGJcm0Pct3XExcEesW5 languages/protobuf.min.js
sha384-DEtb/ZdhjW1Cdv5xvRxclWJbLAKYAG6OzVAzZYZ9reKrFh00+TkFo9w9Ljb0Fazg languages/purebasic.min.js
sha384-+C04DKgtZnHAhHZItae9fqXLpFEOyUHN6kobxpiLSPBg17g5JVKlb1ysp/CZwTb/ languages/python-repl.min.js
sha384-UNylCl24YSCblAMsh3SJhmMxC1aShY3GXXzV6Fn+gwnM6jqEbktBi4xU35iS+v5r languages/python.min.js
sha384-JVzbEYzxEwQkAYjLZg3IBrkL5H9dwDZyPhXjWRwmYQ36dGqnTH3ICuiTZ5aRQsOW languages/q.min.js
sha384-BnMiFScmIea4WjBm4YUS0HQiA3B4dq2NHoJZwbyCyvxSl/AV1KwoznFwK9SDb06j languages/qml.min.js
sha384-74nXqonaqrSmWq7B0iarUPx37REtTkUTgxwaST3LnNwiMJZwlOqdEkrbnas5TQHe languages/r.min.js
sha384-MMLa+bUDdjsOVUTKUvImPItmGxFYALycIcwiAj1fK+iShqA6VkSijkDVFsVrgNIE languages/reasonml.min.js
sha384-Cd0HNKpIuKqUafjAyTKZXNEDi4h4587EIqElJtLRFkMLGRIyM9+zJUR6eWkhX5oa languages/rib.min.js
sha384-oxeSXMIVjZnnYy40g7YlxtDFaOOZ6xqxD0pkfb/Jk8cKyPyZZRIwjj381atgt+wV languages/roboconf.min.js
sha384-san5mYURldv5lpQx3yw+zckZnYa4GEqBFRhK1iY0P5cm9MTXFfYIcuT18ieaRwmt languages/routeros.min.js
sha384-ikiSG4o7zF7Yjyje0VxT70hwoUXg5B5mBTTYT+hM7bS3CX5HzuLWUrq1kGOXfG9Q languages/rsl.min.js
sha384-tNUpJtGEw6W2uTt0YjHInEjzty7FbSvRP/Y+GEIPVPf3AMm9lMGF8c2ki/+Vpapk languages/ruby.min.js
sha384-hPzMjBjUoFkWEKh55BL5NmKaG7sYGVnD1G3J5kvi/K3Xf58oqRaUCcfWyCL45kfe languages/ruleslanguage.min.js
sha384-/yMDLmNs6+1FNtG9t5CfdXXFZEuVINUHm2hi92zPftRxurkojc+Mojd5jbgeGAX7 languages/rust.min.js
sha384-tsIzAat6/bBp2RVv5S62lXlc1L5rT6cGd5mgpcXcPFkbIRAQEfX26l+mdbDwkupH languages/sas.min.js
sha384-NHrBqvANhZCTze6Z/eeVLmSdxvichUiJph3YLSOawPqB3HhT5pAxAMRMUtIB6DXp languages/scala.min.js
sha384-N5oQqT6CkHjmvZFuYAYQd+WKVHJaRNNFezs/spJ5ZrN5yi2JAFD7r69Bp5VwEav8 languages/scheme.min.js
sha384-LPTl+wiDySvOBKuoMBDXiDOHR2HuG/ODIKbs/8mpGtbaDCcgEv20b4zOaY6qpffS languages/scilab.min.js
sha384-xvCaNtGi57qL/FY7VPww2me48uqLcsY+mWv/jarC8u4VQt9/6+3OJ0Xdt+okNdZg languages/shell.min.js
sha384-GhhIkrqpIzhzmOpmjv5ILW+XB4tLnnQoODX2PLlZSmQXnottpZ9WPOGDiLCVWiug languages/smali.min.js
sha384-jDv6eW+BglxpgSj0wij67P/5ElsrWm4pBFK+ucwm+H4MnsWpKgTHUabAb7jWQMdU languages/smalltalk.min.js
sha384-e5Nfd3qNlMX5jhY7RkDc/KgbdKNmB3pcL0e4f/663fcMucSz4HObcwD2XAm2ekpI languages/sml.min.js
sha384-B+2bfwVGfINC0JKyX4uXYRQoMm1J7uKtB/rN/LTlBEGegycTBx5fJDBEYGEAeCLf languages/sql.min.js
sha384-xvXNI30Eqbll5aH0hQfZgfeRvMSsp9kaz2ptFz/dBw/Rof7SGHSOTVttyPiYMWHC languages/stan.min.js
sha384-AOcTD5YjtUi4RWjEua9wGkhESjH26HgvKQ0M+xlLMqQa8j/wJjQiCfxNFH5Riweo languages/step21.min.js
sha384-9F6TQnwg/NJrptNjtB+bgsbkn/H/lQGwBsPft+A7E9xCTDf85AOhO2hhLXCJBrPc languages/subunit.min.js
sha384-CUy06fA07bmOqnSdERIKLxcXCZNbrnGSMLDZlFefbni4US+WU4CEsOIAX0Ofh3L2 languages/taggerscript.min.js
sha384-mEoSMfozXBNEZOVxkcrNvAztOUO6+gwua8wQjkg3DBpG0ZR3fAlgHy1LQHYIsbby languages/tap.min.js
sha384-TtG6PvFoVuJ7u0OdiRKWwlxRJX3ZEmi19xCGY7Nd4iuqBVCWt56FfQQcYi0pGwsw languages/tcl.min.js
sha384-8n1ziTezBOYDE5RI8yIJBhRKChF/BVx+S2CQKEqUFHpSuvW3Xb4SxkNkY+YAHbnj languages/thrift.min.js
sha384-WX0WnHmK4AzU0IZ11vmI9s1G+8Cg1icAVpHiExIyvLOse0VWprmnmZyf9ubbTetm languages/tp.min.js
sha384-amAm9VtL43Ymw/BSJBIaj4RiJFO3xISMWJe3dsuXSTXyHKgRRpsL+he1eeBTgJMC languages/twig.min.js
sha384-Bwl0IRX/Ma4kmRrmaDFOala6SndGyeNdBy9cYoPTlq+Brd0o8veFiHH3g6WpRxaO languages/vala.min.js
sha384-v/Aqn7AFBBly6vML4bU8j32GVKXDnP6pOhE0jSJwbbQDL0LGaqM3FRjuajl1Aybi languages/vbnet.min.js
sha384-KKiz4clp6KsGPVYo/g2VjJNU+Q3z+FZpy5/WWp66MWvk5K2dv4h2fr5gXY0tBpxZ languages/vbscript-html.min.js
sha384-E4JiIEDvZKkEZscCGdSmvIi6oiiQU6VFZu9oRYTxZ4HtFg0gnKX03R/L49W5daaL languages/dockerfile.min.js
sha384-Kdxk1bGLTCO/oDKV9zwAYoPeev3tB8zzJo7CE+SO2Ik3PARNvN6LGawGH8UvXBoD languages/vbscript.min.js
sha384-nija1bp8K+nR1H9gN50n4pHLsEcdsTk54oQzp4ruXw5oMEvGsMg0nTuLEKX3Td+o languages/vim.min.js
sha384-M94BevYKwZsG4J7gpBWAXkS49ve9Y9V5XQqQgaPF61RDgRkGWNUnzpu1WJ1l4gUE languages/vhdl.min.js
sha384-2CeiimLNPBOWiPKTvQMCiD4so9ddy1NJvDRXqWIrWMDF4d4Ozi/wVPs534LnsusM languages/wren.min.js
sha384-+Zzz41QGOX6IiIJ0onfVeoH8Mg84y8YwkfpukzvT4z0yJZFSB2eQXAcKssGbtZzM languages/wasm.min.js
sha384-XaDVLAHxM8715CQG5o3sB/r0mPzI5M0Op77drRxB6tJrgRIhAa1kG8zDeHLFQ5uk languages/xl.min.js
sha384-FVB3yVD9MiIEqaTSoswBvFtTwba4z3c9IdTGEh0ubuDsnpqQhgQTvtSh0RaOMWdv languages/xml.min.js
sha384-vyD81rNWQzwKf4H+tbkxHvyPJm1p8BS7+yZ9Rjo2d9IgOt4cD4TDceuJdOykcf/F languages/xquery.min.js
sha384-pJ8zjMK0BpqlxN0Xxm8yv7I85RUkEAbg0M5+T9p9fkmBFateyFYonlTC9fI7J0mN languages/zephir.min.js
sha384-sEDe4WwJDp9ixjAN2eO9s3HTvqH3kI1+8xqvIwhv268ButBdDQ3/XLt7ercpL84i languages/yaml.min.js
sha384-PZkvV9UsMPQhjJczpo22Ya6qMzaPEVv4YZMxRnXW55LYItMMmE1pyXU2VFvImlp+ languages/lasso.min.js
sha384-02SGnth/iHYzgb6bpeKMrTA5YqOmYwLD3XH6NEwycICl7UwcelnFv5Crp/xr7OOw languages/verilog.min.js
sha384-i0IhHUho7rbdOr0rBRi41zYoGUzBuzFD4w9Jj2PavFB++I+LHURzMbrlJCgFdgKt languages/gauss.min.js
sha384-X1wx722+UonoHvow5CqkCh8KDrS+TsmsbUeLu8YErSwE/GDj9P5Az02VLqVGzO+U languages/mel.min.js
sha384-RrRo1mbWN8rr8jempcuZ9lGP6DGUvxsK6NpAjdBvMuNnyMqqXloBHHZBku3T+hEb languages/pgsql.min.js
sha384-TbYxWeqMgQowfpG0De1Dw9ncLu6Z38Argjh1QcHq0DucfHmdQorhI6JjHyKMBQo3 languages/dust.min.js
sha384-kUrVryrLhlijlJzMxQuY5wSMj0ufCmziiFAEG1rRmGc3D40EGREZj/yR8APScIMa languages/dts.min.js
sha384-UQnPRzlFbQo2SApQDUbuHCtFIFsCgFSqhuow0iQ/Lo/YLs7UWXW5pwPr1dyPGtu5 languages/ebnf.min.js
sha384-wwbe+GCYdBzQ9EaB5Fd1EOlZvLKJS0v1iKTYSkrjPNnHYGuzelFjtGks9AjKoDR5 languages/stata.min.js
sha384-bWgEEZ2f+kD0WDBfJonIunvrFXrguLr40sg8EZkSo+dGnb8E+krViel2UZJ5SeY2 languages/x86asm.min.js
sha384-LPgbQ18n2rAdtQii+8Qlh059Ga1fgZ3mG4W3YQniQ6kBxBp3NwsNliro3YeUyn0q languages/maxima.min.js
sha384-U+o4cQV/i1X6bElYt1+oWxfzkO0+4GqPwBbRmqEyXbNxqavDKJ0uwU3vgNWAuG3K languages/1c.min.js
sha384-dANKmoz1WEsej40wOSDcGTszMsrLS680SyyZWHAAwL1SJwy7FvJZ43ee4TUoznLb es/languages/abnf.min.js
sha384-6j8Q+Eh6WL5TZ7f8GsqyR3GxoHiuDxI9E1vYbpj4IxOfIBYENBw+Y6lqlWS+tCZz es/languages/accesslog.min.js
sha384-wN1ORvqmipm4V+whizy/hNoP0pTc3mGTTPvf7cSsx7R/TNd1HMn0t/E1sMRQStU/ es/languages/ada.min.js
sha384-j5oMikRJJf52S5BdwUppdI+oiDkL0ZBWeECh1KSctVnyPwdIN7IAUswvYNNjNVhK es/languages/actionscript.min.js
sha384-zM4gfs7+imw06rWt0GmfmB/tLQNshfxH9LMEJF+jDZg/gMe6FnPyz+oOT+Wb47ZO es/languages/angelscript.min.js
sha384-6r/b1ntUsxjoBdlF9wyOHiBgKWpOyem7j8DW4SjYct+kOEW6opgDj5j74/na6iLF es/languages/apache.min.js
sha384-C1ogptcfBMl+37TLllQt49npgFvHCStW9w79FXszmN1YDKObtXWX266nP5EcCg3h es/languages/applescript.min.js
sha384-5kU2A2lL5N8cJrY6W0FnYfBrlMBbbbH0gER+eUFvlCcf/NiKO150Urr+39aXK5BU es/languages/arcade.min.js
sha384-jic83KQC6yBX86RHjSSCUZGaK+a5WMT33WqPozaE7lYd+72tJ2VyLSVrJobVAn8l es/languages/armasm.min.js
sha384-c/jvy1BZXPOyv7cbssJdgRyPDY3zwpjBvn5Id78bEnK5jltIRTTiQSeT+JPUfC7G es/languages/asciidoc.min.js
sha384-dCLjru0FkJsiuzMk+oIprvORgipU3RiGb3FrA9MOBtqwSpYZqCcMPpWIFQt7QIfS es/languages/aspectj.min.js
sha384-iCCJqU9SHXd0QHqc/MkGUAMp30lLF23hipKKbn/0CvVdg6quFjiy6gX9661OLeIi es/languages/autohotkey.min.js
sha384-QLP2FzeSLaAJRSn9p5YYPWy7/AWOdrIv3MV4h4ehPQjj7NOaZXw1iOc0Sf87npNC es/languages/autoit.min.js
sha384-sR/L3s8jfdk0LJ1qMGdKEUXLuJKdbn0x3Qs7gcq2TxCakyYFY/CsMPnGN2jkQ7I2 es/languages/avrasm.min.js
sha384-SVb4exN3Mo2bs63/HRFkUwg+SNn6wSO9FZS4KARIdwy2lihPba8OZWmppnaO0bD5 es/languages/awk.min.js
sha384-K56IZmFLswqfxfGCLbNWr4bhKz1++L5pI0d3xPn6F0igFYZMNHK+PtcAJqj/ulsT es/languages/axapta.min.js
sha384-Ckj7HR6MmVJEvW7ARqjgLSjqLyRS14lEXwMHCQ93+ZvCbZ6osBJgCqfaf2ubrnFb es/languages/bash.min.js
sha384-RWhc+PAFScZ3HXLcljWFFtaVzAj6Bf1olH8XvYbZDwzq6BjpyTYeNcX+XVNJ4Cl8 es/languages/bnf.min.js
sha384-DuqaSZOxRAfE8QmrC9cwUNYwjng/nWq8kVYjNKmXxQIk0PirOcNMBwqM80UiXzxz es/languages/basic.min.js
sha384-dEz71uVFJAciKTeWLJaQ4hDGao0jubMR7+zMRlKSIKnOZVvDl+Ryj7iEUMkSn22a es/languages/brainfuck.min.js
sha384-pG+OilECqb6F1YBrJ6+gMks3LirD25EOiMymXhRA8TiYmFyWHEOepH6nSlujh+OZ es/languages/c.min.js
sha384-FTvwXT0HX8GLG98ng67qrBtM0jHo8/CxYYQZBEEVPjUv/MyZj2a7yf4GqkIAqUO5 es/languages/cal.min.js
sha384-QjnV7NMYxRffesTbSWxYxO2YZz5HlG9EpmOavb0NZbeiVCPD8nrIHxltghLx/Ki1 es/languages/capnproto.min.js
sha384-zLYqjrPsP7E/rvUUyF+oqU7Vorn2/z7fQ/UvA5j2qwsNpQm+g0Oc1MHxZP+sItIV es/languages/ceylon.min.js
sha384-HUFZbQVU1TOwIfUq+izXuYWSc6VF4q72NuvTVuijl06Wm69ytZ7r2niMqJZQIgJ8 es/languages/clean.min.js
sha384-UuNtV968f+QQL8kBesWAGoCOwlWS5+RejZH65IMixQ3qaL3j/cWhr21IzTZHN/M4 es/languages/clojure-repl.min.js
sha384-dt81yn1PbDSnsEN99oX6+bdQGYWT0aSyNJ/WfvkMaz10L0J+J1Ynbb0F3uILWzlz es/languages/clojure.min.js
sha384-pcYXLXUCwOefQf9cRBJ8HT2iwOnSAGxGVmEsoX9aaNVN6qRF5Sdt/nsG5MdYOJFT es/languages/cmake.min.js
sha384-+GHiOBNPHnW+OOYhB488EutCAPeRaMa6HTdBD1dYxEtbo5AflgVciQtl4snXWAwh es/languages/coq.min.js
sha384-mgjVkOofGX/966vOufrq4QnS/LcpsVLEIqiuPCE6IvAlWibY2XZhuV7evEcBv7pR es/languages/cos.min.js
sha384-04ExtDMIDK/5L24PxuAgZl9vGFFe82bcLfWG7ZR05ThS3qXU9D4KlhFtC5DxDjlr es/languages/cpp.min.js
sha384-2gFQS1qhyFG16CgQUPwKBI418Ndo+toU6GnWNQuHfBGHRvGJUXyTTClaEHdgGckM es/languages/crmsh.min.js
sha384-g2DM2duFPtDy2pr4RWgt5OkFN2Js0lq78fXh+llA9gPIaLmYTrrE1FizEbGsoCDE es/languages/crystal.min.js
sha384-+jG4piZNhV7UmLWG38Qwp3OAvRVo4Wf7nRk8WcvdPZ3WcQDTNWWk0jKQ7B9kcKaB es/languages/csharp.min.js
sha384-LjwodVb23DxcQJPbOu++D2ZFhSMoNGLuACD1OaikEl5HJDcHqdwacnhpaK6hnIJJ es/languages/csp.min.js
sha384-tu9Bf0OCIvrRvl6qPGGHhOPdv/7QGY45JQGuNkQQTFlwwS0iZw9g/Sm8UTmskHCg es/languages/d.min.js
sha384-twbQTy3YBvivkB3WV/m+K8QHOOb32ddH89dxaGmknktwzBuFsqU8RaDTZItOn+lc es/languages/dart.min.js
sha384-QsJGdbNPSIm16MyP0w/CpBXLQWN1cjq3Rtci+UxVDokzn3u09uR7XNAu2dyr7bLw es/languages/delphi.min.js
sha384-bBvrnYG0VdHeN2t2jnGQrRNs7qusYpc0LF0C1DJxsAf3fVu8Z8iqFjlzXisGFLXh es/languages/diff.min.js
sha384-twKG02DoRGtg2kP3389q+bkaNJvkU/hXkM4Q8iuqXQ48b1UXMt0jeehmTYJgW4pE es/languages/django.min.js
sha384-ta08IRFzXRmJQ15cV5z+KkcZwcriHQ4VeMHQ/aZc33thoiWv/B3+lSj9tm7/GfhH es/languages/dns.min.js
sha384-y1+gMx0mDNbMUF+LdIgAWo7fSYbBpKWaUGId9onj1ZOp5X+SigIhvhthJRKa6pul es/languages/dos.min.js
sha384-ZycOXryiATRQp2Mq6byhXtBiWo4jZBU/cbAJGZr+I3XwFIpas+nuVcg801/lTHgO es/languages/dsconfig.min.js
sha384-IG0w1rd0UewnFmvKuXD23FZXaeiV4sFfu5KVkMKoRBw1dG9fCraZwMjDUbjqCVYO es/languages/elixir.min.js
sha384-XG2YlWUzE+TH2xGQ1vRp0jor40eAh+qU89Hx4AsNUoTFpR20Ab0apF5qgdHFFwDK es/languages/elm.min.js
sha384-gOGO4jw4FEbhrBJdS7kBsw7xVGdbApINz0SulN2O7OMEU8oqqONWXry9hN0AzNtl es/languages/erb.min.js
sha384-7GNt7zK7iXk2GlZteMGED4E6MYMeoKYlBsui+EBWRf+l21vQQThu6FdXT/d8hfAC es/languages/erlang-repl.min.js
sha384-ozoFJN7C4/H5QeybAedBiz32u6iS6udqdPldezNz2ksgz9UjGVypJiDXYQh0Ui/w es/languages/erlang.min.js
sha384-GxUL3FxK6hh3KdZfBP6bFQRXJGACMPXfsIl64UXNfa08jo9GN5COMdTYwfOoQG69 es/languages/excel.min.js
sha384-bAYel/u6lfpt9sEsBpW/j6TuLg1vS3JRalUTY1a8dz3SM9GYlWJXF20dWrBy84aO es/languages/fix.min.js
sha384-viTCoNOYaLtb/9GihJhLRKR/02PHzbejK/TzqXZ1TT6YxHbnNKtt1y/+6BWJQCwn es/languages/flix.min.js
sha384-57o222IFnmm2K3eAKTNKio/wp2I1G560Q/q4fPW8acC2Lyz64JG32rjmHdaSDiZX es/languages/fortran.min.js
sha384-888SthJiEJl/PbK0VJMXpDDhLBf5k2pTeUhUpa4GEWiIV7jgkQn4R8DU16UkRGCm es/languages/gams.min.js
sha384-sNpNfjIAD1/zInNPYQnW66E/1DWYJtVOvkZCxVxfQzCS5UL/7pp4dkuWps/xPWie es/languages/gcode.min.js
sha384-1qlFNmw4+obTIRp8VJCD0X03UDaE13LvxuBAnQCKFK58ZjkN0YNGPKCnZHEKu8Zw es/languages/gherkin.min.js
sha384-XmHmgiZ5grs6QqDQFkVC3fjaUzS+S1cTiyeikjIiup3gySEt69cBrBhtg+/gr8fD es/languages/glsl.min.js
sha384-k8pT6GU7KpojyvBtwJrci+imG7YLX5gXLD6YPjyiLfJqkYPl65Lqrzb74bLRfapU es/languages/go.min.js
sha384-UmCoQgF6FO67sTRKrYeqe5GOxYJJnDEm/fgL3wgn3nzakT+6t6NwmGptJOmaBP06 es/languages/golo.min.js
sha384-NWHJ9gOrp5p75Er3HPqlKtyrnYCoFt0sJF1tjQ2MfpqIYCqim22bXAUNQUjmVpi5 es/languages/gradle.min.js
sha384-nmWU4bg01z9w0pxj10nKSdYnYWcNPg2ivboQasvTD0P+ala8JmSjb9CKlIAY5vDk es/languages/graphql.min.js
sha384-bZYiapvGiaqK+DCbaUZry0G5Bfy/zIh/WmE+u6u4eZg4FNLvA2zCKKaLqbfNCaw4 es/languages/groovy.min.js
sha384-887/cBUH867Z26E6W2zdPJ81Uabyz/WmxYR3MqDS5lU6kDL1aGmTnn9md+EuzSDD es/languages/haml.min.js
sha384-86UOUHqoDtJ52DxnVrZPotVHqpUHXS7SGwRmMLldjIAdTW/IKf76kywgL8iXr/8m es/languages/handlebars.min.js
sha384-VOdhMMm94IX0hefUdtI5/YIRP8uVzJqNxljqp9MGU7UtM1IFsfMNe6y9RlKbeu1b es/languages/haskell.min.js
sha384-A4cF7el+Nr85gVTyO73TJBXtKNBJAT7L1W5ytfX5yn2ylJ/lNGm3mwlXgHY3JKl8 es/languages/haxe.min.js
sha384-cv3H+YZad8UNRUThTTJvSIqnFYKZyyAGrojqYkE8Mi8TdBaelmgM5jlR9dtq6ejU es/languages/hsp.min.js
sha384-eGVyJEgcYiluUW7rAQJaa2XUQ2/t+kgA7ALhTgni2JI6kZBZ8GjT/QENSxlSMiI5 es/languages/http.min.js
sha384-uIfj5yn9F/cARBZkA6OI7s+FYciLHb/Mp6ZkyaWY4oZwy9o2p0SGuajWw8K5///y es/languages/hy.min.js
sha384-dSH+5jGIG5LmRzIAgCJszS2EkSLqDv+cpk1WuJQGzqkK9+iqvkz4QTP9KfmPwx70 es/languages/inform7.min.js
sha384-d1dqGCLKv3jYMBLyhsZJFKKI6wpfJ+5EiMyiE7v5sDhyb/TSPxT+yHHy9BvRJ4J1 es/languages/ini.min.js
sha384-NvYCwV6T001Mp1cJ5CGnPMINnSLMItSaondMr2BfyfsEIO4QBeJMbur2Ap2yWd/C es/languages/irpf90.min.js
sha384-hnkYRxskUoaYpIbe6ED7oEmDwO8ZLxutb/LiOqlNWaq/HYkvBJvfJ0f5cKh93zXW es/languages/jboss-cli.min.js
sha384-4iFy699h2AThAKa6Cu9Wp1sA5VHQ1qssaev0wMGTi+ZhRdfhl2vbtrrAcDSACZ1U es/languages/json.min.js
sha384-HwaPrlO7yoey14b84rCamIlNmuboy6t/MUwLn8+4lSTFKGfkEJ9Qxz4Mf9mOFTJC es/languages/julia-repl.min.js
sha384-rqhiWmxiX063hF0iQVTsbktXWD2XD3iTfqC80fXtSW2zKmAbC/XwuDkoCfuDxeEV es/languages/julia.min.js
sha384-RYxI6WGmUdDqipOXs//zrVAqaZNxI2mgMGCbsUzbfQtj7hbsmK8ByAQou6utWizO es/languages/latex.min.js
sha384-uL1D3/NhUakrvrkf2s4DESmGjvC2tDvc21UAySMX52ZpphQJUZ7WKFFO71FsoCQz es/languages/ldif.min.js
sha384-C+BqS3kSqeGFF1cdN647qNJ9s7V283r0FyLp7DRcxA2n9gpxg3UiaDRWYs4tFBmV es/languages/leaf.min.js
sha384-iu5ZJiUyy0YsgnvZP47KcO2ta9b+5KCz5YsSd5plxiYKuN1Q926h4KgB3VXzF4mg es/languages/lisp.min.js
sha384-IEW2Uk8xBOIeO2iX24k1qlfgibeGa5Jd6lV/PQGpBq6aMWq9/el4MVXSP2U3UyV/ es/languages/livecodeserver.min.js
sha384-Nh1DtcD10yO3qxD9yNb0WTUoLLVaunH/glZhydFUmR9Li35SJr4huiUU96kKISv2 es/languages/llvm.min.js
sha384-us4nsYC8RhosPWgApTNUSvdU8atxSLKxoMXEeS9hMJj579lxhTHdWUbEhvVTJ0y0 es/languages/lsl.min.js
sha384-8F6b8Yu6QZagyrqBClwhLnlrDw6Oa6ULGIFqMekVQGzmNTd/VZZUqrLYRrQmCHps es/languages/lua.min.js
sha384-LoX1FbysuPbTkk6OLG+NXSWH//WmIXpk0v8lU0zs8RyryIZ/1Sr91H8j2vOEh86X es/languages/makefile.min.js
sha384-dypCZyTQdxf7aBOJpbAXSc01d3Bdn6bhVkPv8+0AwIPu8jp8jZZWsthjAMinLdhP es/languages/markdown.min.js
sha384-hZpRDO+MVxtA3xrGlsrNIqQad78SzXKrY1MoHA3CMsGHF3j1lKOSZqUYL34v5VAr es/languages/matlab.min.js
sha384-hTYvgCvXl1SvkgI6bAjT2NagRWMip0osMMxNYhD72bYn7mw4LwtzkGPf/pWZdRJY es/languages/mercury.min.js
sha384-bSZFvXuc+YAYJw2abBalUo5Qj/hFicc3jgHOyGorvmYmKtFCsqGQtWruAzzQAdRE es/languages/mipsasm.min.js
sha384-AgpzHjmWfTo9nJxYF7IMbviDDFV7h7E0lXRSu+uqDxnAYBUm3Ib0Firmujodkxja es/languages/mizar.min.js
sha384-xEhpltJq8tKFuiUHSWCiIaQ/crGHOD7RO+zN1lQs2/PcgmJfvvVMEHBonCCBBIRQ es/languages/mojolicious.min.js
sha384-GbNtFqlUpawlcTem+jPw9QPMwDWEJy0iL4zD/lhvYSxwoRE5rMvGKR+J2r494lG7 es/languages/monkey.min.js
sha384-rqhGk+8I8w1kpUCsd5SLmkfvr5H3N/wAKsc2iJ9DZcMevpL0zc7C2acBatLrH6hb es/languages/n1ql.min.js
sha384-ncJWJC1TD1WAzL1wEImKE+WBtesqFjmhlVYQNLe1Yb1cI3Wp2RW+O6a0OHpml8Eo es/languages/moonscript.min.js
sha384-hQvjhT599HcYrFTZR6GGWbhIkD4CyCydnZPvLVlIbVWyDMEFj8a5hWLrnwxCLSBO es/languages/nestedtext.min.js
sha384-9h6UIRAL+oOtfqfq/c3p80q8+KVa+xGI1TTpa8UrEJGK8iNpuS6qY+kOSB+/z8Zs es/languages/nginx.min.js
sha384-mra9DwEdXlVCFhnGfB451rvSNUO740cYR/vkkbLkYFxS3KH2+zfu/FRYVEvI+W9Y es/languages/nim.min.js
sha384-R8CSUGO358K9SNbliKlWj7XPNbV+7W/jMnK1uUYj8HY+6PMYWQlRtZaysKlcw8Vy es/languages/nix.min.js
sha384-nLSw4XzkpMH2N+6w2fpfwQGXftycPejJ0Ys0QyDfv5OqNkJ4i3wdS1jbfIlg8jXl es/languages/node-repl.min.js
sha384-/JYAehuOAh5LND3cVHMYk14WbSuz9sjCcFKperC9TF92tPb4WCosLISDBCfumPz6 es/languages/objectivec.min.js
sha384-m8K/c+e9JfwCQtl9QqBaHLs+0Zrs2i3xO/jUfHOgKu5ep3bDMY4bEN+DwMknnqfr es/languages/ocaml.min.js
sha384-waSSFj65fSI8TQEt2AeI5cvWATgDAeX1oClKxZyU12Jd5unkwflh/HmLAvDIr3zM es/languages/openscad.min.js
sha384-lptiIfVPjDLRhU+1QOS3e1Wq8j1BkPL16ahaN++zIPrhlmHt7q+VfyNvme24vQbJ es/languages/oxygene.min.js
sha384-ZvF6dA9kl72cl9lHO+OcUqzBIw9OeQAyRK9E0UdGrPC+q53CgDe8eV7EnipRIwI7 es/languages/parser3.min.js
sha384-v1Tu00y0dqM/ZRB7/NPKTqXUqGOtiUObWa52PAC+sFhsaZ3DHM7zO6aZG3TUu4LD es/languages/perl.min.js
sha384-r1NkVoY7LppmMl1SQ7ilT7Nl6Rq0BsqRqTnXHk3Vmm4RPm/++0wsYWA01FgaFHqd es/languages/pf.min.js
sha384-iLU/+xvNHNoRbI37k4dErCB39VxP9qrMepDbE7/ejjwYBphPyFrXnZZsWdsMWEfV es/languages/php-template.min.js
sha384-QaHhqF5wzEQYvFGOkgXsahDt/oZzy8+BvV/LUpxWnUHr1R+Gjk4rrcCEcG7CraGc es/languages/php.min.js
sha384-RWP/7AqQTa3+kmLLDv3Btcp5VUjbF5zjDNtZkxEzKzSfOnP8I6xIGXfH7Jv9ZeG7 es/languages/plaintext.min.js
sha384-mQ4aLvcKkJqvJ4oMfBXtqRxKUOKCkacof9OY2+R7RtAeypc0HnK2/pcv4oUoORd0 es/languages/pony.min.js
sha384-TLDfvNoU19c4/R/+yP+Uxd63go7xCKmOMBLFIrzTFZVFisNsnIgKj/yx/mX5Kj7H es/languages/powershell.min.js
sha384-uRdcjr4vBKy0NH6r6J8KJy1HHaDOmHTjUp7TrWUsqz1pLTrWGSn4xKS3RAwYSH2N es/languages/processing.min.js
sha384-NaNqf+aK2hK5w2Pelt3jLkYaNltJbXJuxncWVM2As9efini0fR1vxhU+O9i5iJTm es/languages/profile.min.js
sha384-VAdFzYjOvBIXhpT1bvxwizPq8bSLFZTa3yS6HyZxsWwWquS6nXDNBTJNY8LvbcZV es/languages/prolog.min.js
sha384-TKDwj3yQb9B/yMQzszt541Psw/AvvJPPvVtHtlgKx7RzXQRSPAQ7PPOtKiAHjxlK es/languages/properties.min.js
sha384-9fndm543Kvyzdnl5u7aSPnV6N7FBqo29l8Kc5yiVMjRRtaUUm76b0xUJO3pGB3R3 es/languages/puppet.min.js
sha384-q+feDGJLXuR4ncl6uVtjkkDcSeNVbs0Uj0xyE6P9ssAl9PMMpIxGOKxtOC9S6R9q es/languages/protobuf.min.js
sha384-RzshGEqLl7w1Vt49AEszKk/E6kyNVaTMDVs3c6WGHr9CvGCS6AHDYFOhsq1YaZA1 es/languages/purebasic.min.js
sha384-sOv6Ca/LnL1klX9uP7EjwPFBu1hTR6wVMcWHbTq/COg4d/CqFVTVTmfVFj8c6IYy es/languages/python-repl.min.js
sha384-A9lZ84uy+tY7JAOr4FdDwxAaCZF9i2PEMNygvQ+2BDo54mFMOmw5pLdsxuS2MdoY es/languages/python.min.js
sha384-gJkjxl+mbsSO0OfvJ3FmVhLzfIizhwB9Pbu4i5FMpvebX2lcCdKKbrbADdCipYpt es/languages/q.min.js
sha384-CBOPpljdr9ODGv7CAyMUGUKZ9T/kGh3voUvEPf1OwcAftcwwAViPv57dt/dWvp0Z es/languages/qml.min.js
sha384-vaMut1DkdxmJadYZs6f1Bm5gv0Y5VWX/cUxEmfQedZ9xzR1qGXSsXKtrbpYQawh+ es/languages/r.min.js
sha384-Z22fCwzNgoBtMvTfdVgSijeRZp5eEFiG5ZAkqVHOt9TD0ykD0jE+AGcxcjchbCeh es/languages/reasonml.min.js
sha384-jfrJbXy1Ts9mKxPYatXCNkv3feJuC8pArMY23TUG244kzlnBDqbpe9zBVv2oB9i9 es/languages/rib.min.js
sha384-kYZbA+zfBix5Tqs/dyfTBi7chkSX6GRvXDApZbmVitUBCgOXJMNV2pfpmVAnunPs es/languages/roboconf.min.js
sha384-zejC5wc8blAATXp+fB2Ay7+I9xh5Z4kUNZkGetEigmjnx5cezrkuOzwJMDbHm++Y es/languages/routeros.min.js
sha384-RFqRkCXygUmMmTURPo0EtAWmlNy8Cs6MyK/BZONz+xU1aL8mNV9mio3bBv7n0sk1 es/languages/rsl.min.js
sha384-5X1pSIfMmAedvnkB56KNad0QgC1+C4LFUvkNczA9QLVBVbtyU+FjmrhwGcNVbiso es/languages/ruby.min.js
sha384-+DqP3HNZyxn8DhsuuN2GXGQ+enkll8azA/9QJBeoxMm6BmExdsGIAJO3OnbfZd0t es/languages/ruleslanguage.min.js
sha384-PP4hISX+VxUMZnoPgfnCyOQukI6JR7xvgrrpFvcXMeGeEJMb6U8UQw4zHTlTTwoi es/languages/rust.min.js
sha384-6yoDyB4IJej93y5NrlarxsHbQ6A7fd0QEBg2CKOCiDSveM/FbdN3uPrVbfXQS8BO es/languages/sas.min.js
sha384-d1AcYdRolhQxNrsnz23vSB7Dr1stkfueGcI1zXhcwYHJvI1tN1EQ9TrZvUTNoD26 es/languages/scala.min.js
sha384-jJEUSQ0cYQOk0a26y35n7ghaymVULE+zpyL8IjQ/JaWI+FYEi9RT2AH87phuAchf es/languages/scheme.min.js
sha384-mFN2VbhyezBHdITKpAdX98wqdS30iBu/wvrcm+GpZSuhoj/Oae2Hgi2WZ1xx0hiu es/languages/scilab.min.js
sha384-qxmw0TUjiw3Yki8p+sHF2gpG7kG76tfT76engiOB3vTsywL71GW4LYyo+PFf3CUO es/languages/shell.min.js
sha384-rawZx4VK16x9cI9wcRwVsPiC21vC8Mo+dpqbAsuVi0uO8VBBXV5fwmxpEDwBm5R5 es/languages/smali.min.js
sha384-VLHr3OqNxzBeuvivGLoDg6GW/lfbvzfkq4wnHz+xRGDeZ7Muf+TiSGovHzpOQZxt es/languages/smalltalk.min.js
sha384-FmuPHr6g1yhTlWTzFWcsz3mFwHcpD6S3XB7JARoiF/AM6Ne3q9zUfNj35JQCcBft es/languages/sml.min.js
sha384-xMaL4s7f/pTYLhicsNGD+9tyBwUfk/bD3f0aykmEqi+Jfwg1gh8fcbQPchhjx3PG languages/sqf.min.js
sha384-8+AI3Xp7m6yKMLUkDISQcT3jjrppvoX6UULFzaE3+NOl1MGP2va0lfMh11AsKexb es/languages/sql.min.js
sha384-ZnQK4afl/KjleUzj3pk8aail0kO2NNA5gsxuLwhxxHYKRBWJiJawNHB27Q6yPLUY es/languages/stan.min.js
sha384-heQvyZskID3PvrprabbzG+Tllrk5iQr5kCn7zWMQrb4nwuvYLaNfKEiGt0xqFH/G es/languages/step21.min.js
sha384-yQ7zmxTsp4hOa8adHOYjQ1qNpRdfBKYePnOla4QX+nKpPtEb6WJKeRnKMjqx+Hsq es/languages/subunit.min.js
sha384-8rwGPJk/UB9Wq0gfQCkA/JdE+f49yh2pNHUxvQb2kgCouSHtXG53G+SbROM+H2c4 es/languages/taggerscript.min.js
sha384-ULtPvgY95V9opRfIgexaOg/+6O2FHnl+kU2LwoXihG3BbCMRULwe9BhbbZBrqUjy es/languages/tap.min.js
sha384-lePHB2jnoD6KrKJ7fcTEbb/TIkamWpATFHhhLDHkfwiTvz8PmQWHrgPtyXMNQPQH es/languages/tcl.min.js
sha384-tKnGgb1A/KsJ1Uj9XE2z7Hk97Zk9aGNdr1U3EHL4P+Fz9exheg//Yqw9ePdP+BTI es/languages/thrift.min.js
sha384-nDmStDnzfatkbBuPtifQ0D0a+Ke985m2NF/gwW0s8RjoFk/Z/xklI0Mr4y+Dhd+1 es/languages/tp.min.js
sha384-Vl8kAkJYspBSVuI73LbxR8lU5tVPSjEP5wX4HJV4rQlefPXZHaHZkcEJCk1f+jQj es/languages/twig.min.js
sha384-yEiBzFBp8ujTN+mKEG4lufN+wrLbIiNxeyLUJkTn4MSU4n9IoV6277ooUFyy8RTM es/languages/vala.min.js
sha384-3F0HQYRgqdeQkjVjtaXFhk+LE13IBwGTwt2h2PMqGyI1eRSJvOlvB7L7PDsCu4G9 es/languages/vbnet.min.js
sha384-CuBX7elly8CVaulpmlnqZ9lXbyYf2Y9ooXrR7b/yl/OnFUVTxDcpx3hiuOtwDrau es/languages/vbscript-html.min.js
sha384-YQqlwD+6rmEJUhL6TBzu+jAEbjE1IKlvUpiz1K+vWkc1zNPybGCdD/tQtc0/mtJS es/languages/dockerfile.min.js
sha384-Nj/2pMUWQKTUoKNCWXA39MNyy0xhvs9QUBm7/0qT/Ieefcl6pDhX5YYfrIJFTSLb es/languages/vbscript.min.js
sha384-hZy5IRMwQkySnA82IbQH36fOsa4WfFic1pxLhWJ15768hHt+KPjPTJWnq8e/26NN es/languages/vim.min.js
sha384-Mc2qGgzIz/kW4Bow5QEuFA24C6FVVpXl04AXtnqOi0f/55jgYd5mmGL20+sPGPA5 es/languages/vhdl.min.js
sha384-t/fl4UztyknE6AxWC/pvEwcsw2AHxONOmGBzbe5N4mndza1NUY1EHQR+IXO4OX7I es/languages/wren.min.js
sha384-LfB+2GlRZ1+Lhj0x7vOATbNV2stWn12i3Qv1PfSLRYbh90u98AslqFHK9adtq2kN es/languages/wasm.min.js
sha384-ZWy+DfapEt98sCPqsCVXAt7GZ8YxiOemqdtRMDVONxkD6X26yKsXUrbFFP7HWiAY es/languages/xl.min.js
sha384-b+rblwMnFUeIhgTDd7f6aCBrKChZXeIaRadHgqIpjcIZPK8gIgC9OsBdtSjOhAG7 es/languages/xml.min.js
sha384-JuKGjYxpBVWuzWh7HMjQRDV51tbqs7Bgse6rBhESkz1RKFn/8TQ7f1I3+be5JmHa es/languages/xquery.min.js
sha384-dogVpnJx3uWzS5SOeHH68IkmVbycBjC2VwnQ8AylshZ2YWeiQax5+jPoyjQXfeY/ es/languages/zephir.min.js
sha384-30zuXhx+xovC1UHPzol2MNU19uKLMH6JGB7RsMh8MSPEdF97QMT/LekqhCVAQ/vO es/languages/yaml.min.js
sha384-MHgECBucXPQGq3phUOowOoC3xa45PygwV1kqWTKLWCX2K40iHd0aAOpYdtkjV1Hg es/languages/lasso.min.js
sha384-WC28P1PinQ6493T+DJM1H502Dk+YkFQmFuPggq8Jf5E3gzBo9aXYrIeV6gtSWG49 es/languages/verilog.min.js
sha384-ezw6MlZUSpOF9Qkf2gq/3qQBUHBh/I+khFGU4LAFNa5+mRds9Ow1jBpWTWFoLe/T es/languages/gauss.min.js
sha384-OoFYKXoucEJx0J/RQcrn0HO8VRnnzF7OaEX/mkJEA10qggT+54rI644sAAR2BgIC languages/gml.min.js
sha384-m7zS83P2gd9049Xrsu1JFKji+ebT23Zxgkc8vHdJYmv86w4rh36/cmlFuxLBAsPR es/languages/dust.min.js
sha384-D6wMMqjtVHVgtokf+ymdGfwC/0vnlWGxkQf9VG/AM/jmBn7eBbUYCHN8Knpj8gLz es/languages/dts.min.js
sha384-gmhWaPRaCnWGcbOEfLyi1Gul6wbeweLxKBy/qYRgBeQfag7Sk0JQVKDdWK1TfLXz es/languages/ebnf.min.js
sha384-6/n/W6Q8MuY6IxPVaIlYzBGstFYyIiCFoNkLMw8nUGrn2s0dwSwShrWj1TYiglUP es/languages/mel.min.js
sha384-V/wMebIO+06VZAgcK8Um0FYE4hFVmsEk1cgzBli/A748yuCji4kL7P7lZvSNMOs2 es/languages/pgsql.min.js
sha384-SZ1oBbSW5Nox2sysrNKPxs84+cNLLfopzDCkre3tEcfEovMyzuq1nPQatZgrjk2+ es/languages/stata.min.js
sha384-S3+E6yEiH4xpnKZNmvM5WbwsE3rceLYchrjVQyCHRTWLZp24SyqVXpBHZ3SFeLzZ es/languages/x86asm.min.js
sha384-/SGDqlO5ZcdGVIDk7oqjEMLXfuuLfoGlzM8O01aHevd/9V4dX3UAhME+uGkwvMF3 languages/isbl.min.js
sha384-ipv/gL2d8elywdHjKjIG55ZiYQ7iKHgrvu1n6y8g+uIqq66oDnlw9yb9eBXFqdLj es/languages/maxima.min.js
sha384-VnvU4wIAwqruSEEft1MvwE+up12l1eAM4m00TOZYzTfnnWw6eF+lqpfrX8hX/cgd es/languages/sqf.min.js
sha384-xzyG65fTar5vKqc90yjIHyzak9RYgZMPFnSnvaQVOHDXxNTON5l1CZBdrR2ie/x+ es/languages/gml.min.js
sha384-4F7+YMvwROaUXec2WtKAsOidj+h77w0tsRpfFQuig8E48uwMaxi9HyTgWMhT9wpD es/languages/isbl.min.js
sha384-nZcZuq+IWzH3X6XFBu1kCVXwVu7tYiRRFbjoEkvG/krppu+elID0KVb+eYM4yNXl es/languages/1c.min.js
sha384-9UbzYddbIOWRdm1AbEHNNBqGOU0xkCPDIusMsI7/Yh5OPUv2Qq8xjBZ/U8nCvsYq languages/arduino.min.js
sha384-PWgDryoMBftO+s4ZuGYMHUgdgozhn61s3rHoBbzCezv/UIk0OeAt6TMXCZ1PgwpZ languages/fsharp.min.js
sha384-kGICnodCuKTxr07tAMdGZLJsLb+qJPOYm4P0dK/OmNFmsWWMCNlrw18MG2+IgJCI languages/nsis.min.js
sha384-DRPrAm1Vf7rbCT5ON39RGDYNNzx885BDG0OInLnfKYN9VXJ82DsmduKIAoHAa6N8 languages/coffeescript.min.js
sha384-tj1k6lwYiZ1IxiQ8/VVcJzaNdnZcVI/P6WuEuTI7N/pHNevcz0xpMCAALb+w7GUE languages/livescript.min.js
sha384-ufJ6hbXihIfbvzVKpURE2ibCaUdzc774E32OMTdUYP+64SL7VrAg1+25Dvo3P0HA languages/javascript.min.js
sha384-Yie8bl/G/oZU61aAtB/VgwroAdm/SI/2Kwfgt1jRhJ1awfsUbrjtkVExp+yfSxQz languages/css.min.js
sha384-64PqwrXCCWWpgElQvT+6Yz5RLe5JYdM3imsQ0R5JT2yFcGajzTVlLpvgBqNgC2mS languages/less.min.js
sha384-5QiS3LLW6RyAW3665wjQrOMDb1KDgS1BUnMH7KnAzOH5VtVdsStQI1ZBOF1Y4EK9 languages/scss.min.js
sha384-/ElKLVWViRkHfnVLPVnVPG0Jbctm1Ucpq9+IstC5sItpa/0KapsUXFX/4ni79pFi languages/stylus.min.js
sha384-lRBwbqXdUqmGhUW5kP2Q/Uc7KLgEVWq5A8+oSuLqmcF1hqY6KuWtnBSG5EBgzN8W languages/kotlin.min.js
sha384-1SDgvDHfSPGuNre5ss3hfslVZKi6Rxd7yzyD8oGB7esismrJ7KcZmhN/OAD0ba1v languages/java.min.js
sha384-P2Unpsr2kBgka1PRhIROanPGtx9cRVQJiYnIO6afD9vR1u3DCH5euLmAeOBJ4BEy es/languages/arduino.min.js
sha384-21VlixU/yyYwbxTEv+CWxfUlGGsgEiecCldpEFiqE2YKZRXvgie+UrI101xc6PkD es/languages/fsharp.min.js
sha384-IKYVhc+7z0kw3CuG1a7fw1yRtOTv3M8OV1Q2Jfvv4VQxO9ZNAaL63xQ2m6eigJq6 es/languages/nsis.min.js
sha384-Fid9yaBoCTs23mNBhuxn9+cHWbz6FwF4RA6pLL1b+G8SQdZrhKP6wm+FUBpkG1Xi es/languages/coffeescript.min.js
sha384-OmIpQammgtf9oDJ5CjrZZyOg/xkAT7h94dTvKdgn07JzPHj0gu5nt0OnPeTi1l/j es/languages/livescript.min.js
sha384-WqTkDxKv/jhzBuspJwgQgrTsh6xm6ohoAKgBFfuzwlgc9f6NaE2MPZV5+e8jT9ra es/languages/javascript.min.js
sha384-AGQpnj6TgROC2xmpyPQq0phI4Q2pmMZHUCctaYF0+L4VFA5O6jg5zuh5/ywhOTF2 es/languages/css.min.js
sha384-aMGalTlm9FUiDAYox0uWzlmAL8kKL4rI0oneBsX/sykC2y2cyG/sP+Ok/96eDE6I es/languages/less.min.js
sha384-5Jj0iW/QobPfSvJkB0Bi8Q4cjWiJjfDx2eHuf2YO62joQHE5GYNxy/UfvY4+8Sv3 es/languages/scss.min.js
sha384-EuRaOHJWfHs7RnPBO7nObaGr4w1y/G2qlqnE0qPMSHjrNkUz1NtEgJ2u6QsO1pxF es/languages/stylus.min.js
sha384-zjyzKlrzk21TshJ8WZQfYf3wXeWPeSTiKA7WVtqdoSGl6vpJfByms8unJ43wHuVr es/languages/kotlin.min.js
sha384-P/AcSYNNEjuSX5TocPlVIvgqhICOSFkI8mEFCb/sQr3iC8pleBexShwZ/cjdsjqb es/languages/java.min.js
sha384-5vlF1zvKNZMtcEohfUHIOH14jXpI2v7itw/0IkbHsqLE/ryeVMDBg/+cPDjA3XwR languages/mathematica.min.js
sha384-hDErGvCgcXyDxejYQx3SlY88932urw1Eu7tCQHFsgQWN0uHv583m97QeO8FGjKtg es/languages/mathematica.min.js
sha384-rQrSKf5GDWRzi0k70rO5ifbhjp0oyke6fqq13YPHSWO9m6L4SFMcboqVv/gpGkn1 languages/swift.min.js
sha384-NE35KqKCp2+muTWjMMtRF2DfZ9uNi+4Xr2pqQl0GAtjchC2jH+D9CjP2XZaJD2gE languages/typescript.min.js
sha384-pNlRsYniTibIy++kIgXgTYrO1xmUy9rtXno20X7EXRZgtvSMvmVC6b3EQ3W1p264 es/languages/swift.min.js
sha384-/qIXK3k2pgnhfKdGSqGc8HryiTyMooCq2fWWLHQzDWgbGs+tHAvlzrxvryQl4RFC es/languages/typescript.min.js
```
