// Register the markup language
hljs.registerLanguage('markup', function (hljs) {
    var XML_IDENT_RE = '[A-Za-z0-9\\._:-]+';
    var TAG_INTERNALS = {
        endsWithParent: true,
        illegal: /</,
        relevance: 0,
        contains: [
            {
                className: 'attr',
                begin: XML_IDENT_RE,
                relevance: 0,
            },
            {
                begin: '=',
                relevance: 0,
                contains: [
                    {
                        className: 'string',
                        endsParent: true,
                        variants: [
                            {
                                begin: /"/,
                                end: /"/,
                            },
                            {
                                begin: /'/,
                                end: /'/,
                            },
                            {
                                begin: /[^\s"'=<>`]+/,
                            },
                        ],
                    },
                ],
            },
        ],
    };
    return {
        name: 'Markup',
        aliases: ['html', 'xml', 'xhtml', 'rss', 'atom', 'xjb', 'xsd', 'xsl', 'plist'],
        case_insensitive: true,
        contains: [
            {
                className: 'meta',
                begin: /<![a-z]/,
                end: />/,
                relevance: 10,
            },
            hljs.COMMENT(
                '<!--',
                '-->',
                {
                    relevance: 10,
                }
            ),
            {
                className: 'tag',
                begin: '<style(?=\\s|>|$)',
                end: '>',
                keywords: 'style',
                contains: [TAG_INTERNALS],
                starts: {
                    end: '</style>',
                    returnEnd: true,
                    subLanguage: ['css', 'xml'],
                },
            },
            {
                className: 'tag',
                begin: '<script(?=\\s|>|$)',
                end: '>',
                keywords: 'script',
                contains: [TAG_INTERNALS],
                starts: {
                    end: '</script>',
                    returnEnd: true,
                    subLanguage: ['javascript', 'handlebars', 'xml'],
                },
            },
            hljs.COMMENT(
                '<%',
                '%>',
                {
                    relevance: 10,
                }
            ),
            hljs.COMMENT(
                '<\\?',
                '\\?>',
                {
                    relevance: 10,
                }
            ),
            {
                className: 'tag',
                begin: '</?',
                end: '/?>',
                contains: [
                    {
                        className: 'name',
                        begin: /[^\/><\s]+/,
                        relevance: 0,
                    },
                    TAG_INTERNALS,
                ],
            },
            {
                className: 'attr',
                begin: /\s/,
                end: /\s/,
                contains: [hljs.QUOTE_STRING_MODE],
                relevance: 0,
            },
            {
                className: 'string',
                begin: /"/,
                end: /"/,
                contains: [hljs.BACKSLASH_ESCAPE],
            },
            {
                className: 'string',
                begin: /'/,
                end: /'/,
                contains: [hljs.BACKSLASH_ESCAPE],
                relevance: 0,
            },
            hljs.NUMBER_MODE,
        ],
    };
});